@@ -16,13 +16,12 @@
 
 """Command-line interface to the OpenStack APIs"""
 
-import locale
 import sys
+import warnings
 
 from osc_lib.api import auth
 from osc_lib.command import commandmanager
 from osc_lib import shell
-import six
 
 import openstackclient
 from openstackclient.common import clientmanager
@@ -32,33 +31,34 @@ DEFAULT_DOMAIN = 'default'
 
 
 class OpenStackShell(shell.OpenStackShell):
-
     def __init__(self):
-
-        super(OpenStackShell, self).__init__(
+        super().__init__(
             description=__doc__.strip(),
             version=openstackclient.__version__,
             command_manager=commandmanager.CommandManager('openstack.cli'),
-            deferred_help=True)
+            deferred_help=True,
+        )
 
         self.api_version = {}
 
         # Assume TLS host certificate verification is enabled
         self.verify = True
 
+        # ignore warnings from openstacksdk since our users can't do anything
+        # about them
+        warnings.filterwarnings('ignore', module='openstack')
+
     def build_option_parser(self, description, version):
-        parser = super(OpenStackShell, self).build_option_parser(
-            description,
-            version)
+        parser = super().build_option_parser(description, version)
         parser = clientmanager.build_plugin_option_parser(parser)
         parser = auth.build_auth_plugins_option_parser(parser)
         return parser
 
     def _final_defaults(self):
-        super(OpenStackShell, self)._final_defaults()
+        super()._final_defaults()
 
         # Set the default plugin to admin_token if endpoint and token are given
-        if (self.options.endpoint and self.options.token):
+        if self.options.endpoint and self.options.token:
             # Use token authentication
             self._auth_type = 'admin_token'
         else:
@@ -93,10 +93,13 @@ class OpenStackShell(shell.OpenStackShell):
                     if version_opt not in mod_versions:
                         sorted_versions = sorted(
                             mod.API_VERSIONS.keys(),
-                            key=lambda s: list(map(int, s.split('.'))))
+                            key=lambda s: list(map(int, s.split('.'))),
+                        )
                         self.log.warning(
-                            "%s version %s is not in supported versions: %s"
-                            % (api, version_opt, ', '.join(sorted_versions)))
+                            "{} version {} is not in supported versions: {}".format(
+                                api, version_opt, ', '.join(sorted_versions)
+                            )
+                        )
 
                 # Command groups deal only with major versions
                 version = '.v' + version_opt.replace('.', '_').split('_')[0]
@@ -104,7 +107,7 @@ class OpenStackShell(shell.OpenStackShell):
                 self.command_manager.add_command_group(cmd_group)
                 self.log.debug(
                     '%(name)s API version %(version)s, cmd group %(group)s',
-                    {'name': api, 'version': version_opt, 'group': cmd_group}
+                    {'name': api, 'version': version_opt, 'group': cmd_group},
                 )
 
     def _load_commands(self):
@@ -113,8 +116,7 @@ class OpenStackShell(shell.OpenStackShell):
         osc-lib has no opinion on what commands should be loaded
         """
         # Commands that span multiple APIs
-        self.command_manager.add_command_group(
-            'openstack.common')
+        self.command_manager.add_command_group('openstack.common')
 
         # This is the naive extension implementation referred to in
         # blueprint 'client-extensions'
@@ -126,11 +128,10 @@ class OpenStackShell(shell.OpenStackShell):
         #         'show_repo=qaz.github.repo:ShowRepo',
         #     ],
         # }
-        self.command_manager.add_command_group(
-            'openstack.extension')
+        self.command_manager.add_command_group('openstack.extension')
 
     def initialize_app(self, argv):
-        super(OpenStackShell, self).initialize_app(argv)
+        super().initialize_app(argv)
 
         # Re-create the client_manager with our subclass
         self.client_manager = clientmanager.ClientManager(
@@ -139,42 +140,10 @@ class OpenStackShell(shell.OpenStackShell):
             pw_func=shell.prompt_for_password,
         )
 
-    def prepare_to_run_command(self, cmd):
-        """Set up auth and API versions"""
-
-        # TODO(dtroyer): Move this to osc-lib, remove entire method when 1.4.0
-        #                release is minimum version is in global-requirements
-        # NOTE(dtroyer): If auth is not required for a command, skip
-        #                get_one_Cloud()'s validation to avoid loading plugins
-        validate = cmd.auth_required
-
-        # Force skipping auth for commands that do not need it
-        # NOTE(dtroyer): This is here because ClientManager does not have
-        #                visibility into the Command object to get
-        #                auth_required. It needs to move into osc-lib
-        self.client_manager._auth_required = cmd.auth_required
-
-        # Validate auth options
-        self.cloud = self.cloud_config.get_one_cloud(
-            cloud=self.options.cloud,
-            argparse=self.options,
-            validate=validate,
-        )
-        # Push the updated args into ClientManager
-        self.client_manager._cli_options = self.cloud
-
-        return super(OpenStackShell, self).prepare_to_run_command(cmd)
-
 
 def main(argv=None):
     if argv is None:
         argv = sys.argv[1:]
-        if six.PY2:
-            # Emulate Py3, decode argv into Unicode based on locale so that
-            # commands always see arguments as text instead of binary data
-            encoding = locale.getpreferredencoding()
-            if encoding:
-                argv = map(lambda arg: arg.decode(encoding), argv)
 
     return OpenStackShell().run(argv)
 
