@@ -81,10 +81,20 @@ class PortTests(common.NetworkTagTests):
         self.addCleanup(self.openstack, f'port delete {id1}')
         self.assertEqual(self.NAME, json_output.get('name'))
 
+        # sg for port2
+        sg_name1 = uuid.uuid4().hex
         json_output = self.openstack(
-            f'port create --network {self.NETWORK_NAME} {self.NAME}x',
+            f'security group create {sg_name1}',
             parse_output=True,
         )
+        sg_id1 = json_output.get('id')
+        self.addCleanup(self.openstack, f'security group delete {sg_id1}')
+        json_output = self.openstack(
+            f'port create --network {self.NETWORK_NAME} '
+            f'--security-group {sg_name1} {self.NAME}x',
+            parse_output=True,
+        )
+
         id2 = json_output.get('id')
         self.assertIsNotNone(id2)
         mac2 = json_output.get('mac_address')
@@ -113,6 +123,12 @@ class PortTests(common.NetworkTagTests):
         id_list = [item.get('ID') for item in json_output]
         self.assertIn(id1, id_list)
         self.assertIn(id2, id_list)
+        item_sg_map = {
+            item.get('ID'): item.get('Security Groups') for item in json_output
+        }
+        self.assertIn(id1, item_sg_map.keys())
+        self.assertIn(id2, item_sg_map.keys())
+        self.assertIn([sg_id1], item_sg_map.values())
 
         # Test list --mac-address
         json_output = self.openstack(
@@ -127,6 +143,17 @@ class PortTests(common.NetworkTagTests):
         self.assertNotIn(mac1, item_map.values())
         self.assertIn(mac2, item_map.values())
 
+        # Test list --security-group
+        json_output = self.openstack(
+            f'port list --security-group {sg_id1}',
+            parse_output=True,
+        )
+        item_map = {
+            item.get('ID'): item.get('Security Groups') for item in json_output
+        }
+        self.assertNotIn(id1, item_map.keys())
+        self.assertIn(id2, item_map.keys())
+
         # Test list with unknown fields
         json_output = self.openstack(
             'port list -c ID -c Name -c device_id',
@@ -262,3 +289,82 @@ class PortTests(common.NetworkTagTests):
             f'{self.base_command} create --network {self.NETWORK_NAME} {args} {name}',
             parse_output=True,
         )
+
+    def _trunk_creation(self):
+        pport = uuid.uuid4().hex
+        sport1 = uuid.uuid4().hex
+        sport2 = uuid.uuid4().hex
+        trunk = uuid.uuid4().hex
+        json_output = self.openstack(
+            'port create ' f'--network {self.NETWORK_NAME} {pport}',
+            parse_output=True,
+        )
+        pport_id = json_output.get('id')
+        json_output = self.openstack(
+            'port create ' f'--network {self.NETWORK_NAME} {sport1}',
+            parse_output=True,
+        )
+        sport1_id = json_output.get('id')
+        json_output = self.openstack(
+            'port create ' f'--network {self.NETWORK_NAME} {sport2}',
+            parse_output=True,
+        )
+        sport2_id = json_output.get('id')
+
+        self.openstack(
+            f'network trunk create --parent-port {pport} {trunk}',
+        )
+        self.openstack(
+            f'network trunk set --subport port={sport1},'
+            f'segmentation-type=vlan,segmentation-id=100 {trunk}',
+        )
+        self.openstack(
+            f'network trunk set --subport port={sport2},'
+            f'segmentation-type=vlan,segmentation-id=101 {trunk}',
+        )
+
+        # NOTE(ralonsoh): keep this order to first delete the trunk and then
+        # the ports.
+        self.addCleanup(self.openstack, f'port delete {pport_id}')
+        self.addCleanup(self.openstack, f'port delete {sport1_id}')
+        self.addCleanup(self.openstack, f'port delete {sport2_id}')
+        self.addCleanup(self.openstack, f'network trunk delete {trunk}')
+
+        return pport_id, sport1_id, sport2_id
+
+    def check_subports(self, subports, pport_id, sport1_id, sport2_id):
+        self.assertEqual(2, len(subports))
+        for subport in subports:
+            if subport['port_id'] == sport1_id:
+                self.assertEqual(100, subport['segmentation_id'])
+            elif subport['port_id'] == sport2_id:
+                self.assertEqual(101, subport['segmentation_id'])
+            else:
+                self.fail(
+                    f'Port {pport_id} does not have subport '
+                    f'{subport["port_id"]}'
+                )
+            self.assertEqual('vlan', subport['segmentation_type'])
+
+    def test_port_list_with_trunk(self):
+        pport_id, sport1_id, sport2_id = self._trunk_creation()
+
+        # List all ports with "--long" flag to retrieve the trunk details
+        json_output = self.openstack(
+            'port list --long',
+            parse_output=True,
+        )
+        port = next(port for port in json_output if port['ID'] == pport_id)
+        subports = port['Trunk subports']
+        self.check_subports(subports, pport_id, sport1_id, sport2_id)
+
+    def test_port_show_with_trunk(self):
+        pport_id, sport1_id, sport2_id = self._trunk_creation()
+
+        # List all ports with "--long" flag to retrieve the trunk details
+        port = self.openstack(
+            f'port show {pport_id}',
+            parse_output=True,
+        )
+        subports = port['trunk_details']['sub_ports']
+        self.check_subports(subports, pport_id, sport1_id, sport2_id)
