@@ -10,9 +10,7 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
-import argparse
 from unittest import mock
 
 from osc_lib.cli import format_columns
@@ -20,26 +18,24 @@ from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.tests.unit.identity.v3 import fakes as project_fakes
-from openstackclient.tests.unit import utils as tests_utils
+from openstackclient.tests.unit import utils as test_utils
 from openstackclient.tests.unit.volume.v2 import fakes as volume_fakes
 from openstackclient.volume.v2 import volume_snapshot
 
 
 class TestVolumeSnapshot(volume_fakes.TestVolume):
-
     def setUp(self):
         super().setUp()
 
-        self.snapshots_mock = self.app.client_manager.volume.volume_snapshots
+        self.snapshots_mock = self.volume_client.volume_snapshots
         self.snapshots_mock.reset_mock()
-        self.volumes_mock = self.app.client_manager.volume.volumes
+        self.volumes_mock = self.volume_client.volumes
         self.volumes_mock.reset_mock()
-        self.project_mock = self.app.client_manager.identity.projects
+        self.project_mock = self.identity_client.projects
         self.project_mock.reset_mock()
 
 
 class TestVolumeSnapshotCreate(TestVolumeSnapshot):
-
     columns = (
         'created_at',
         'description',
@@ -56,7 +52,8 @@ class TestVolumeSnapshotCreate(TestVolumeSnapshot):
 
         self.volume = volume_fakes.create_one_volume()
         self.new_snapshot = volume_fakes.create_one_snapshot(
-            attrs={'volume_id': self.volume.id})
+            attrs={'volume_id': self.volume.id}
+        )
 
         self.data = (
             self.new_snapshot.created_at,
@@ -77,11 +74,15 @@ class TestVolumeSnapshotCreate(TestVolumeSnapshot):
 
     def test_snapshot_create(self):
         arglist = [
-            "--volume", self.new_snapshot.volume_id,
-            "--description", self.new_snapshot.description,
+            "--volume",
+            self.new_snapshot.volume_id,
+            "--description",
+            self.new_snapshot.description,
             "--force",
-            '--property', 'Alpha=a',
-            '--property', 'Beta=b',
+            '--property',
+            'Alpha=a',
+            '--property',
+            'Beta=b',
             self.new_snapshot.name,
         ]
         verifylist = [
@@ -107,13 +108,14 @@ class TestVolumeSnapshotCreate(TestVolumeSnapshot):
 
     def test_snapshot_create_without_name(self):
         arglist = [
-            "--volume", self.new_snapshot.volume_id,
+            "--volume",
+            self.new_snapshot.volume_id,
         ]
         verifylist = [
             ("volume", self.new_snapshot.volume_id),
         ]
         self.assertRaises(
-            tests_utils.ParserException,
+            test_utils.ParserException,
             self.check_parser,
             self.cmd,
             arglist,
@@ -122,21 +124,21 @@ class TestVolumeSnapshotCreate(TestVolumeSnapshot):
 
     def test_snapshot_create_without_volume(self):
         arglist = [
-            "--description", self.new_snapshot.description,
+            "--description",
+            self.new_snapshot.description,
             "--force",
-            self.new_snapshot.name
+            self.new_snapshot.name,
         ]
         verifylist = [
             ("description", self.new_snapshot.description),
             ("force", True),
-            ("snapshot_name", self.new_snapshot.name)
+            ("snapshot_name", self.new_snapshot.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.volumes_mock.get.assert_called_once_with(
-            self.new_snapshot.name)
+        self.volumes_mock.get.assert_called_once_with(self.new_snapshot.name)
         self.snapshots_mock.create.assert_called_once_with(
             self.new_snapshot.volume_id,
             force=True,
@@ -149,13 +151,18 @@ class TestVolumeSnapshotCreate(TestVolumeSnapshot):
 
     def test_snapshot_create_with_remote_source(self):
         arglist = [
-            '--remote-source', 'source-name=test_source_name',
-            '--remote-source', 'source-id=test_source_id',
-            '--volume', self.new_snapshot.volume_id,
+            '--remote-source',
+            'source-name=test_source_name',
+            '--remote-source',
+            'source-id=test_source_id',
+            '--volume',
+            self.new_snapshot.volume_id,
             self.new_snapshot.name,
         ]
-        ref_dict = {'source-name': 'test_source_name',
-                    'source-id': 'test_source_id'}
+        ref_dict = {
+            'source-name': 'test_source_name',
+            'source-id': 'test_source_id',
+        }
         verifylist = [
             ('remote_source', ref_dict),
             ('volume', self.new_snapshot.volume_id),
@@ -178,49 +185,39 @@ class TestVolumeSnapshotCreate(TestVolumeSnapshot):
 
 
 class TestVolumeSnapshotDelete(TestVolumeSnapshot):
-
     snapshots = volume_fakes.create_snapshots(count=2)
 
     def setUp(self):
         super().setUp()
 
-        self.snapshots_mock.get = (
-            volume_fakes.get_snapshots(self.snapshots))
+        self.snapshots_mock.get = volume_fakes.get_snapshots(self.snapshots)
         self.snapshots_mock.delete.return_value = None
 
         # Get the command object to mock
         self.cmd = volume_snapshot.DeleteVolumeSnapshot(self.app, None)
 
     def test_snapshot_delete(self):
-        arglist = [
-            self.snapshots[0].id
-        ]
-        verifylist = [
-            ("snapshots", [self.snapshots[0].id])
-        ]
+        arglist = [self.snapshots[0].id]
+        verifylist = [("snapshots", [self.snapshots[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.delete.assert_called_with(
-            self.snapshots[0].id, False)
+            self.snapshots[0].id, False
+        )
         self.assertIsNone(result)
 
     def test_snapshot_delete_with_force(self):
-        arglist = [
-            '--force',
-            self.snapshots[0].id
-        ]
-        verifylist = [
-            ('force', True),
-            ("snapshots", [self.snapshots[0].id])
-        ]
+        arglist = ['--force', self.snapshots[0].id]
+        verifylist = [('force', True), ("snapshots", [self.snapshots[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.delete.assert_called_with(
-            self.snapshots[0].id, True)
+            self.snapshots[0].id, True
+        )
         self.assertIsNone(result)
 
     def test_delete_multiple_snapshots(self):
@@ -252,17 +249,18 @@ class TestVolumeSnapshotDelete(TestVolumeSnapshot):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         find_mock_result = [self.snapshots[0], exceptions.CommandError]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             try:
                 self.cmd.take_action(parsed_args)
                 self.fail('CommandError should be raised.')
             except exceptions.CommandError as e:
-                self.assertEqual('1 of 2 snapshots failed to delete.',
-                                 str(e))
+                self.assertEqual('1 of 2 snapshots failed to delete.', str(e))
 
             find_mock.assert_any_call(
-                self.snapshots_mock, self.snapshots[0].id)
+                self.snapshots_mock, self.snapshots[0].id
+            )
             find_mock.assert_any_call(self.snapshots_mock, 'unexist_snapshot')
 
             self.assertEqual(2, find_mock.call_count)
@@ -272,47 +270,42 @@ class TestVolumeSnapshotDelete(TestVolumeSnapshot):
 
 
 class TestVolumeSnapshotList(TestVolumeSnapshot):
-
     volume = volume_fakes.create_one_volume()
     project = project_fakes.FakeProject.create_one_project()
     snapshots = volume_fakes.create_snapshots(
-        attrs={'volume_id': volume.name}, count=3)
+        attrs={'volume_id': volume.name}, count=3
+    )
 
-    columns = [
-        "ID",
-        "Name",
-        "Description",
-        "Status",
-        "Size"
-    ]
-    columns_long = columns + [
-        "Created At",
-        "Volume",
-        "Properties"
-    ]
+    columns = ["ID", "Name", "Description", "Status", "Size"]
+    columns_long = columns + ["Created At", "Volume", "Properties"]
 
     data = []
     for s in snapshots:
-        data.append((
-            s.id,
-            s.name,
-            s.description,
-            s.status,
-            s.size,
-        ))
+        data.append(
+            (
+                s.id,
+                s.name,
+                s.description,
+                s.status,
+                s.size,
+            )
+        )
     data_long = []
     for s in snapshots:
-        data_long.append((
-            s.id,
-            s.name,
-            s.description,
-            s.status,
-            s.size,
-            s.created_at,
-            volume_snapshot.VolumeIdColumn(
-                s.volume_id, volume_cache={volume.id: volume}),
-            format_columns.DictColumn(s.metadata),
-        ))
+        data_long.append(
+            (
+                s.id,
+                s.name,
+                s.description,
+                s.status,
+                s.size,
+                s.created_at,
+                volume_snapshot.VolumeIdColumn(
+                    s.volume_id, volume_cache={volume.id: volume}
+                ),
+                format_columns.DictColumn(s.metadata),
+            )
+        )
 
     def setUp(self):
         super().setUp()
@@ -326,23 +319,21 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
 
     def test_snapshot_list_without_options(self):
         arglist = []
-        verifylist = [
-            ('all_projects', False),
-            ('long', False)
-        ]
+        verifylist = [('all_projects', False), ('long', False)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.list.assert_called_once_with(
-            limit=None, marker=None,
+            limit=None,
+            marker=None,
             search_opts={
                 'all_tenants': False,
                 'name': None,
                 'status': None,
                 'project_id': None,
-                'volume_id': None
-            }
+                'volume_id': None,
+            },
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
@@ -350,9 +341,12 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
     def test_snapshot_list_with_options(self):
         arglist = [
             "--long",
-            "--limit", "2",
-            "--project", self.project.id,
-            "--marker", self.snapshots[0].id,
+            "--limit",
+            "2",
+            "--project",
+            self.project.id,
+            "--marker",
+            self.snapshots[0].id,
         ]
         verifylist = [
             ("long", True),
@@ -373,8 +367,8 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
                 'project_id': self.project.id,
                 'name': None,
                 'status': None,
-                'volume_id': None
-            }
+                'volume_id': None,
+            },
         )
         self.assertEqual(self.columns_long, columns)
         self.assertEqual(self.data_long, list(data))
@@ -383,30 +377,29 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
         arglist = [
             '--all-projects',
         ]
-        verifylist = [
-            ('long', False),
-            ('all_projects', True)
-        ]
+        verifylist = [('long', False), ('all_projects', True)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.list.assert_called_once_with(
-            limit=None, marker=None,
+            limit=None,
+            marker=None,
             search_opts={
                 'all_tenants': True,
                 'name': None,
                 'status': None,
                 'project_id': None,
-                'volume_id': None
-            }
+                'volume_id': None,
+            },
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
     def test_snapshot_list_name_option(self):
         arglist = [
-            '--name', self.snapshots[0].name,
+            '--name',
+            self.snapshots[0].name,
         ]
         verifylist = [
             ('all_projects', False),
@@ -418,21 +411,23 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.list.assert_called_once_with(
-            limit=None, marker=None,
+            limit=None,
+            marker=None,
             search_opts={
                 'all_tenants': False,
                 'name': self.snapshots[0].name,
                 'status': None,
                 'project_id': None,
-                'volume_id': None
-            }
+                'volume_id': None,
+            },
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
     def test_snapshot_list_status_option(self):
         arglist = [
-            '--status', self.snapshots[0].status,
+            '--status',
+            self.snapshots[0].status,
         ]
         verifylist = [
             ('all_projects', False),
@@ -444,21 +439,23 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.list.assert_called_once_with(
-            limit=None, marker=None,
+            limit=None,
+            marker=None,
             search_opts={
                 'all_tenants': False,
                 'name': None,
                 'status': self.snapshots[0].status,
                 'project_id': None,
-                'volume_id': None
-            }
+                'volume_id': None,
+            },
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
     def test_snapshot_list_volumeid_option(self):
         arglist = [
-            '--volume', self.volume.id,
+            '--volume',
+            self.volume.id,
         ]
         verifylist = [
             ('all_projects', False),
@@ -470,31 +467,37 @@ class TestVolumeSnapshotList(TestVolumeSnapshot):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.list.assert_called_once_with(
-            limit=None, marker=None,
+            limit=None,
+            marker=None,
             search_opts={
                 'all_tenants': False,
                 'name': None,
                 'status': None,
                 'project_id': None,
-                'volume_id': self.volume.id
-            }
+                'volume_id': self.volume.id,
+            },
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
     def test_snapshot_list_negative_limit(self):
         arglist = [
-            "--limit", "-2",
+            "--limit",
+            "-2",
         ]
         verifylist = [
             ("limit", -2),
         ]
-        self.assertRaises(argparse.ArgumentTypeError, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            test_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
 
 class TestVolumeSnapshotSet(TestVolumeSnapshot):
-
     snapshot = volume_fakes.create_one_snapshot()
 
     def setUp(self):
@@ -524,9 +527,12 @@ class TestVolumeSnapshotSet(TestVolumeSnapshot):
 
     def test_snapshot_set_name_and_property(self):
         arglist = [
-            "--name", "new_snapshot",
-            "--property", "x=y",
-            "--property", "foo=foo",
+            "--name",
+            "new_snapshot",
+            "--property",
+            "x=y",
+            "--property",
+            "foo=foo",
             self.snapshot.id,
         ]
         new_property = {"x": "y", "foo": "foo"}
@@ -543,7 +549,8 @@ class TestVolumeSnapshotSet(TestVolumeSnapshot):
             "name": "new_snapshot",
         }
         self.snapshots_mock.update.assert_called_with(
-            self.snapshot.id, **kwargs)
+            self.snapshot.id, **kwargs
+        )
         self.snapshots_mock.set_metadata.assert_called_with(
             self.snapshot.id, new_property
         )
@@ -573,7 +580,8 @@ class TestVolumeSnapshotSet(TestVolumeSnapshot):
     def test_snapshot_set_with_no_property_and_property(self):
         arglist = [
             "--no-property",
-            "--property", "foo_1=bar_1",
+            "--property",
+            "foo_1=bar_1",
             self.snapshot.id,
         ]
         verifylist = [
@@ -591,58 +599,52 @@ class TestVolumeSnapshotSet(TestVolumeSnapshot):
             self.snapshot.id, ["foo"]
         )
         self.snapshots_mock.set_metadata.assert_called_once_with(
-            self.snapshot.id, {"foo_1": "bar_1"})
+            self.snapshot.id, {"foo_1": "bar_1"}
+        )
         self.assertIsNone(result)
 
     def test_snapshot_set_state_to_error(self):
-        arglist = [
-            "--state", "error",
-            self.snapshot.id
-        ]
-        verifylist = [
-            ("state", "error"),
-            ("snapshot", self.snapshot.id)
-        ]
+        arglist = ["--state", "error", self.snapshot.id]
+        verifylist = [("state", "error"), ("snapshot", self.snapshot.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.snapshots_mock.reset_state.assert_called_with(
-            self.snapshot.id, "error")
+            self.snapshot.id, "error"
+        )
         self.assertIsNone(result)
 
     def test_volume_set_state_failed(self):
         self.snapshots_mock.reset_state.side_effect = exceptions.CommandError()
-        arglist = [
-            '--state', 'error',
-            self.snapshot.id
-        ]
-        verifylist = [
-            ('state', 'error'),
-            ('snapshot', self.snapshot.id)
-        ]
+        arglist = ['--state', 'error', self.snapshot.id]
+        verifylist = [('state', 'error'), ('snapshot', self.snapshot.id)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         try:
             self.cmd.take_action(parsed_args)
             self.fail('CommandError should be raised.')
         except exceptions.CommandError as e:
-            self.assertEqual('One or more of the set operations failed',
-                             str(e))
+            self.assertEqual(
+                'One or more of the set operations failed', str(e)
+            )
         self.snapshots_mock.reset_state.assert_called_once_with(
-            self.snapshot.id, 'error')
+            self.snapshot.id, 'error'
+        )
 
     def test_volume_set_name_and_state_failed(self):
         self.snapshots_mock.reset_state.side_effect = exceptions.CommandError()
         arglist = [
-            '--state', 'error',
-            "--name", "new_snapshot",
-            self.snapshot.id
+            '--state',
+            'error',
+            "--name",
+            "new_snapshot",
+            self.snapshot.id,
         ]
         verifylist = [
             ('state', 'error'),
             ("name", "new_snapshot"),
-            ('snapshot', self.snapshot.id)
+            ('snapshot', self.snapshot.id),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -650,19 +652,21 @@ class TestVolumeSnapshotSet(TestVolumeSnapshot):
             self.cmd.take_action(parsed_args)
             self.fail('CommandError should be raised.')
         except exceptions.CommandError as e:
-            self.assertEqual('One or more of the set operations failed',
-                             str(e))
+            self.assertEqual(
+                'One or more of the set operations failed', str(e)
+            )
         kwargs = {
             "name": "new_snapshot",
         }
         self.snapshots_mock.update.assert_called_once_with(
-            self.snapshot.id, **kwargs)
+            self.snapshot.id, **kwargs
+        )
         self.snapshots_mock.reset_state.assert_called_once_with(
-            self.snapshot.id, 'error')
+            self.snapshot.id, 'error'
+        )
 
 
 class TestVolumeSnapshotShow(TestVolumeSnapshot):
-
     columns = (
         'created_at',
         'description',
@@ -695,12 +699,8 @@ class TestVolumeSnapshotShow(TestVolumeSnapshot):
         self.cmd = volume_snapshot.ShowVolumeSnapshot(self.app, None)
 
     def test_snapshot_show(self):
-        arglist = [
-            self.snapshot.id
-        ]
-        verifylist = [
-            ("snapshot", self.snapshot.id)
-        ]
+        arglist = [self.snapshot.id]
+        verifylist = [("snapshot", self.snapshot.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
@@ -711,7 +711,6 @@ class TestVolumeSnapshotShow(TestVolumeSnapshot):
 
 
 class TestVolumeSnapshotUnset(TestVolumeSnapshot):
-
     snapshot = volume_fakes.create_one_snapshot()
 
     def setUp(self):
@@ -724,7 +723,8 @@ class TestVolumeSnapshotUnset(TestVolumeSnapshot):
 
     def test_snapshot_unset(self):
         arglist = [
-            "--property", "foo",
+            "--property",
+            "foo",
             self.snapshot.id,
         ]
         verifylist = [
